@@ -106,8 +106,10 @@ def scrypt(password, salt, N=SCRYPT_N, r=SCRYPT_r, p=SCRYPT_p, olen=64):
         raise ValueError('N value cannot be larger than 2**63')
     if N < 2:
         raise ValueError('N must be a power of two larger than 1')
-    if r == 0 or p == 0:
+    if r <= 0 or p <= 0:
         raise ValueError('r and p must be positive')
+    if r * p >= 2**30:
+        raise ValueError('r * p >= 2 ** 30')
 
     out = ctypes.create_string_buffer(olen)
     ret = _libscrypt_scrypt(password, len(password), salt, len(salt),
